=====================
Distribution packages
=====================

There are separate projects for distribution packages::

 * Ubuntu: https://github.com/midonet/networking-midonet-ubuntu/
 * RHEL: https://github.com/midonet/networking-midonet-el/
